# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_component_dtov2 import ApiComponentDTOV2
from sonatype_iq_api_client.models.api_constraint_violation_dto import ApiConstraintViolationDTO
from typing import Optional, Set
from typing_extensions import Self

class ApiPolicyViolationForDiffDTO(BaseModel):
    """
    ApiPolicyViolationForDiffDTO
    """ # noqa: E501
    component: Optional[ApiComponentDTOV2] = None
    constraint_violations: Optional[List[ApiConstraintViolationDTO]] = Field(default=None, alias="constraintViolations")
    fix_time: Optional[datetime] = Field(default=None, alias="fixTime")
    legacy_violation_time: Optional[datetime] = Field(default=None, alias="legacyViolationTime")
    open_time: Optional[datetime] = Field(default=None, alias="openTime")
    policy_id: Optional[StrictStr] = Field(default=None, alias="policyId")
    policy_name: Optional[StrictStr] = Field(default=None, alias="policyName")
    policy_violation_id: Optional[StrictStr] = Field(default=None, alias="policyViolationId")
    threat_level: Optional[StrictInt] = Field(default=None, alias="threatLevel")
    waive_time: Optional[datetime] = Field(default=None, alias="waiveTime")
    __properties: ClassVar[List[str]] = ["component", "constraintViolations", "fixTime", "legacyViolationTime", "openTime", "policyId", "policyName", "policyViolationId", "threatLevel", "waiveTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiPolicyViolationForDiffDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of component
        if self.component:
            _dict['component'] = self.component.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in constraint_violations (list)
        _items = []
        if self.constraint_violations:
            for _item_constraint_violations in self.constraint_violations:
                if _item_constraint_violations:
                    _items.append(_item_constraint_violations.to_dict())
            _dict['constraintViolations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiPolicyViolationForDiffDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "component": ApiComponentDTOV2.from_dict(obj["component"]) if obj.get("component") is not None else None,
            "constraintViolations": [ApiConstraintViolationDTO.from_dict(_item) for _item in obj["constraintViolations"]] if obj.get("constraintViolations") is not None else None,
            "fixTime": obj.get("fixTime"),
            "legacyViolationTime": obj.get("legacyViolationTime"),
            "openTime": obj.get("openTime"),
            "policyId": obj.get("policyId"),
            "policyName": obj.get("policyName"),
            "policyViolationId": obj.get("policyViolationId"),
            "threatLevel": obj.get("threatLevel"),
            "waiveTime": obj.get("waiveTime")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_report_history_dto import ApiReportHistoryDTO

class TestApiReportHistoryDTO(unittest.TestCase):
    """ApiReportHistoryDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiReportHistoryDTO:
        """Test ApiReportHistoryDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiReportHistoryDTO`
        """
        model = ApiReportHistoryDTO()
        if include_optional:
            return ApiReportHistoryDTO(
                application_id = '',
                reports = [
                    sonatype_iq_api_client.models.api_report_results_dto.ApiReportResultsDTO(
                        application_id = '', 
                        commit_hash = '', 
                        embeddable_report_html_url = '', 
                        evaluation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_for_monitoring = True, 
                        is_reevaluation = True, 
                        latest_report_html_url = '', 
                        policy_evaluation_id = '', 
                        policy_evaluation_result = sonatype_iq_api_client.models.policy_evaluation_result.PolicyEvaluationResult(
                            affected_component_count = 56, 
                            alerts = [
                                sonatype_iq_api_client.models.policy_alert.PolicyAlert(
                                    actions = [
                                        sonatype_iq_api_client.models.action.Action(
                                            action_type_id = '', 
                                            target = '', 
                                            target_type = '', )
                                        ], 
                                    trigger = sonatype_iq_api_client.models.policy_fact.PolicyFact(
                                        component_facts = [
                                            sonatype_iq_api_client.models.component_fact.ComponentFact(
                                                component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                                                    coordinates = {
                                                        'key' : ''
                                                        }, 
                                                    format = '', ), 
                                                constraint_facts = [
                                                    sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                                                        condition_facts = [
                                                            sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                                                condition_index = 56, 
                                                                condition_type_id = '', 
                                                                reason = '', 
                                                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                                                    value = '', ), 
                                                                summary = '', 
                                                                trigger_json = '', )
                                                            ], 
                                                        constraint_id = '', 
                                                        constraint_name = '', 
                                                        operator_name = '', )
                                                    ], 
                                                display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                                                    name = '', 
                                                    parts = [
                                                        sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                                                            field = '', 
                                                            value = '', )
                                                        ], ), 
                                                hash = '', 
                                                pathnames = [
                                                    ''
                                                    ], )
                                            ], 
                                        policy_id = '', 
                                        policy_name = '', 
                                        policy_violation_id = '', 
                                        threat_level = 56, ), )
                                ], 
                            critical_component_count = 56, 
                            critical_policy_violation_count = 56, 
                            critical_sast_policy_violation_count = 56, 
                            grandfathered_policy_violation_count = 56, 
                            legacy_violation_count = 56, 
                            moderate_component_count = 56, 
                            moderate_policy_violation_count = 56, 
                            moderate_sast_policy_violation_count = 56, 
                            sast_alerts = [
                                sonatype_iq_api_client.models.policy_alert.PolicyAlert()
                                ], 
                            severe_component_count = 56, 
                            severe_policy_violation_count = 56, 
                            severe_sast_policy_violation_count = 56, 
                            total_component_count = 56, 
                            total_sast_finding_count = 56, ), 
                        report_data_url = '', 
                        report_html_url = '', 
                        report_pdf_url = '', 
                        scan_id = '', 
                        scan_trigger_internal = True, 
                        scan_trigger_type = '', 
                        scan_trigger_type_display_name = '', 
                        scanner_version = '', 
                        stage = '', )
                    ]
            )
        else:
            return ApiReportHistoryDTO(
        )
        """

    def testApiReportHistoryDTO(self):
        """Test ApiReportHistoryDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_constraint_fact_dto import ApiConstraintFactDTO
from sonatype_iq_api_client.models.api_stale_evaluations_dto import ApiStaleEvaluationsDTO
from typing import Optional, Set
from typing_extensions import Self

class ApiStaleWaiverDTO(BaseModel):
    """
    ApiStaleWaiverDTO
    """ # noqa: E501
    comment: Optional[StrictStr] = None
    constraint_facts: Optional[List[ApiConstraintFactDTO]] = Field(default=None, alias="constraintFacts")
    create_time: Optional[datetime] = Field(default=None, alias="createTime")
    creator_id: Optional[StrictStr] = Field(default=None, alias="creatorId")
    creator_name: Optional[StrictStr] = Field(default=None, alias="creatorName")
    expiry_time: Optional[datetime] = Field(default=None, alias="expiryTime")
    policy_id: Optional[StrictStr] = Field(default=None, alias="policyId")
    policy_name: Optional[StrictStr] = Field(default=None, alias="policyName")
    policy_waiver_reason_id: Optional[StrictStr] = Field(default=None, alias="policyWaiverReasonId")
    reason_text: Optional[StrictStr] = Field(default=None, alias="reasonText")
    scope_owner_id: Optional[StrictStr] = Field(default=None, alias="scopeOwnerId")
    scope_owner_name: Optional[StrictStr] = Field(default=None, alias="scopeOwnerName")
    scope_owner_type: Optional[StrictStr] = Field(default=None, alias="scopeOwnerType")
    stale_evaluations: Optional[ApiStaleEvaluationsDTO] = Field(default=None, alias="staleEvaluations")
    waiver_id: Optional[StrictStr] = Field(default=None, alias="waiverId")
    __properties: ClassVar[List[str]] = ["comment", "constraintFacts", "createTime", "creatorId", "creatorName", "expiryTime", "policyId", "policyName", "policyWaiverReasonId", "reasonText", "scopeOwnerId", "scopeOwnerName", "scopeOwnerType", "staleEvaluations", "waiverId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiStaleWaiverDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in constraint_facts (list)
        _items = []
        if self.constraint_facts:
            for _item_constraint_facts in self.constraint_facts:
                if _item_constraint_facts:
                    _items.append(_item_constraint_facts.to_dict())
            _dict['constraintFacts'] = _items
        # override the default output from pydantic by calling `to_dict()` of stale_evaluations
        if self.stale_evaluations:
            _dict['staleEvaluations'] = self.stale_evaluations.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiStaleWaiverDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "comment": obj.get("comment"),
            "constraintFacts": [ApiConstraintFactDTO.from_dict(_item) for _item in obj["constraintFacts"]] if obj.get("constraintFacts") is not None else None,
            "createTime": obj.get("createTime"),
            "creatorId": obj.get("creatorId"),
            "creatorName": obj.get("creatorName"),
            "expiryTime": obj.get("expiryTime"),
            "policyId": obj.get("policyId"),
            "policyName": obj.get("policyName"),
            "policyWaiverReasonId": obj.get("policyWaiverReasonId"),
            "reasonText": obj.get("reasonText"),
            "scopeOwnerId": obj.get("scopeOwnerId"),
            "scopeOwnerName": obj.get("scopeOwnerName"),
            "scopeOwnerType": obj.get("scopeOwnerType"),
            "staleEvaluations": ApiStaleEvaluationsDTO.from_dict(obj["staleEvaluations"]) if obj.get("staleEvaluations") is not None else None,
            "waiverId": obj.get("waiverId")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.search_result_dto import SearchResultDTO

class TestSearchResultDTO(unittest.TestCase):
    """SearchResultDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResultDTO:
        """Test SearchResultDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResultDTO`
        """
        model = SearchResultDTO()
        if include_optional:
            return SearchResultDTO(
                grouping_by_dtos = [
                    sonatype_iq_api_client.models.grouping_by_dto.GroupingByDTO(
                        additional_info = '', 
                        group_by = '', 
                        group_identifier = 'itemType', 
                        search_result_item_dtos = [
                            sonatype_iq_api_client.models.search_result_item_dto.SearchResultItemDTO(
                                application_category_color = '', 
                                application_category_description = '', 
                                application_category_id = '', 
                                application_category_name = '', 
                                application_id = '', 
                                application_name = '', 
                                application_public_id = '', 
                                application_version = '', 
                                component_hash = '', 
                                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                    coordinates = {
                                        'key' : ''
                                        }, 
                                    format = '', ), 
                                component_label_color = '', 
                                component_label_description = '', 
                                component_label_id = '', 
                                component_label_name = '', 
                                component_name = '', 
                                item_type = '', 
                                organization_id = '', 
                                organization_name = '', 
                                policy_evaluation_stage = '', 
                                policy_id = '', 
                                policy_name = '', 
                                policy_threat_category = '', 
                                policy_threat_level = 56, 
                                report_id = '', 
                                result_index = 56, 
                                sbom_specification = '', 
                                vulnerability_description = '', 
                                vulnerability_id = '', 
                                vulnerability_status = '', )
                            ], )
                    ],
                is_exact_total_number_of_hits = True,
                page = 56,
                page_size = 56,
                search_after = [
                    ''
                    ],
                search_query = '',
                total_number_of_hits = 56
            )
        else:
            return SearchResultDTO(
        )
        """

    def testSearchResultDTO(self):
        """Test SearchResultDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.api_organization_dto import ApiOrganizationDTO
from sonatype_iq_api_client.models.api_organization_list_dto import ApiOrganizationListDTO
from sonatype_iq_api_client.models.move_organization_response_dto import MoveOrganizationResponseDTO

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class OrganizationsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_organization(
        self,
        api_organization_dto: Annotated[Optional[ApiOrganizationDTO], Field(description="The request JSON should include the name of the organization (should be unique), name of the parent organization and tags containing additional organization details. If the parent organization is not specified, this organization will be created under the root organization. Tags represent identifying characteristics of an application. They are created at the organization level and then applied to applications under the organization. The tags can be used to decide which applications will be evaluated against a selected policy.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiOrganizationDTO:
        """add_organization

        Use this method to add a new organization.  Permissions required: Edit IQ Elements

        :param api_organization_dto: The request JSON should include the name of the organization (should be unique), name of the parent organization and tags containing additional organization details. If the parent organization is not specified, this organization will be created under the root organization. Tags represent identifying characteristics of an application. They are created at the organization level and then applied to applications under the organization. The tags can be used to decide which applications will be evaluated against a selected policy.
        :type api_organization_dto: ApiOrganizationDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_organization_serialize(
            api_organization_dto=api_organization_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_organization_with_http_info(
        self,
        api_organization_dto: Annotated[Optional[ApiOrganizationDTO], Field(description="The request JSON should include the name of the organization (should be unique), name of the parent organization and tags containing additional organization details. If the parent organization is not specified, this organization will be created under the root organization. Tags represent identifying characteristics of an application. They are created at the organization level and then applied to applications under the organization. The tags can be used to decide which applications will be evaluated against a selected policy.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiOrganizationDTO]:
        """add_organization

        Use this method to add a new organization.  Permissions required: Edit IQ Elements

        :param api_organization_dto: The request JSON should include the name of the organization (should be unique), name of the parent organization and tags containing additional organization details. If the parent organization is not specified, this organization will be created under the root organization. Tags represent identifying characteristics of an application. They are created at the organization level and then applied to applications under the organization. The tags can be used to decide which applications will be evaluated against a selected policy.
        :type api_organization_dto: ApiOrganizationDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_organization_serialize(
            api_organization_dto=api_organization_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_organization_without_preload_content(
        self,
        api_organization_dto: Annotated[Optional[ApiOrganizationDTO], Field(description="The request JSON should include the name of the organization (should be unique), name of the parent organization and tags containing additional organization details. If the parent organization is not specified, this organization will be created under the root organization. Tags represent identifying characteristics of an application. They are created at the organization level and then applied to applications under the organization. The tags can be used to decide which applications will be evaluated against a selected policy.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """add_organization

        Use this method to add a new organization.  Permissions required: Edit IQ Elements

        :param api_organization_dto: The request JSON should include the name of the organization (should be unique), name of the parent organization and tags containing additional organization details. If the parent organization is not specified, this organization will be created under the root organization. Tags represent identifying characteristics of an application. They are created at the organization level and then applied to applications under the organization. The tags can be used to decide which applications will be evaluated against a selected policy.
        :type api_organization_dto: ApiOrganizationDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_organization_serialize(
            api_organization_dto=api_organization_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_organization_serialize(
        self,
        api_organization_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_organization_dto is not None:
            _body_params = api_organization_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/organizations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_organization(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the organization id to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """delete_organization

        Use this method to delete an existing organization, by providing the organization id.  Permissions required: Edit IQ Elements

        :param organization_id: Enter the organization id to be deleted. (required)
        :type organization_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_organization_serialize(
            organization_id=organization_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_organization_with_http_info(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the organization id to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """delete_organization

        Use this method to delete an existing organization, by providing the organization id.  Permissions required: Edit IQ Elements

        :param organization_id: Enter the organization id to be deleted. (required)
        :type organization_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_organization_serialize(
            organization_id=organization_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_organization_without_preload_content(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the organization id to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """delete_organization

        Use this method to delete an existing organization, by providing the organization id.  Permissions required: Edit IQ Elements

        :param organization_id: Enter the organization id to be deleted. (required)
        :type organization_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_organization_serialize(
            organization_id=organization_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_organization_serialize(
        self,
        organization_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if organization_id is not None:
            _path_params['organizationId'] = organization_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/organizations/{organizationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_organization(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the organization id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiOrganizationDTO:
        """get_organization

        Use this method to retrieve the details of an organization by providing the organization id.  Permissions required: View IQ Elements

        :param organization_id: Enter the organization id. (required)
        :type organization_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_organization_serialize(
            organization_id=organization_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_organization_with_http_info(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the organization id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiOrganizationDTO]:
        """get_organization

        Use this method to retrieve the details of an organization by providing the organization id.  Permissions required: View IQ Elements

        :param organization_id: Enter the organization id. (required)
        :type organization_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_organization_serialize(
            organization_id=organization_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_organization_without_preload_content(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the organization id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_organization

        Use this method to retrieve the details of an organization by providing the organization id.  Permissions required: View IQ Elements

        :param organization_id: Enter the organization id. (required)
        :type organization_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_organization_serialize(
            organization_id=organization_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_organization_serialize(
        self,
        organization_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if organization_id is not None:
            _path_params['organizationId'] = organization_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/organizations/{organizationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_organizations(
        self,
        organization_name: Annotated[Optional[List[StrictStr]], Field(description="Enter the organization names.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiOrganizationListDTO:
        """get_organizations

        Use this method to retrieve organizations with names matching those specified or all if not specified.  Permissions required: View IQ Elements

        :param organization_name: Enter the organization names.
        :type organization_name: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_organizations_serialize(
            organization_name=organization_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_organizations_with_http_info(
        self,
        organization_name: Annotated[Optional[List[StrictStr]], Field(description="Enter the organization names.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiOrganizationListDTO]:
        """get_organizations

        Use this method to retrieve organizations with names matching those specified or all if not specified.  Permissions required: View IQ Elements

        :param organization_name: Enter the organization names.
        :type organization_name: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_organizations_serialize(
            organization_name=organization_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_organizations_without_preload_content(
        self,
        organization_name: Annotated[Optional[List[StrictStr]], Field(description="Enter the organization names.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_organizations

        Use this method to retrieve organizations with names matching those specified or all if not specified.  Permissions required: View IQ Elements

        :param organization_name: Enter the organization names.
        :type organization_name: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_organizations_serialize(
            organization_name=organization_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiOrganizationListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_organizations_serialize(
        self,
        organization_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'organizationName': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if organization_name is not None:
            
            _query_params.append(('organizationName', organization_name))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/organizations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def move_organization(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the id for the organization to be moved under the new parent.")],
        destination_id: Annotated[StrictStr, Field(description="Enter the id for the new parent organization.")],
        fail_early_on_error: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MoveOrganizationResponseDTO:
        """move_organization

        Use this method to change the parent organization.  Permissions required: Edit IQ Elements

        :param organization_id: Enter the id for the organization to be moved under the new parent. (required)
        :type organization_id: str
        :param destination_id: Enter the id for the new parent organization. (required)
        :type destination_id: str
        :param fail_early_on_error:
        :type fail_early_on_error: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._move_organization_serialize(
            organization_id=organization_id,
            destination_id=destination_id,
            fail_early_on_error=fail_early_on_error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MoveOrganizationResponseDTO",
            '409': "MoveOrganizationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def move_organization_with_http_info(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the id for the organization to be moved under the new parent.")],
        destination_id: Annotated[StrictStr, Field(description="Enter the id for the new parent organization.")],
        fail_early_on_error: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MoveOrganizationResponseDTO]:
        """move_organization

        Use this method to change the parent organization.  Permissions required: Edit IQ Elements

        :param organization_id: Enter the id for the organization to be moved under the new parent. (required)
        :type organization_id: str
        :param destination_id: Enter the id for the new parent organization. (required)
        :type destination_id: str
        :param fail_early_on_error:
        :type fail_early_on_error: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._move_organization_serialize(
            organization_id=organization_id,
            destination_id=destination_id,
            fail_early_on_error=fail_early_on_error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MoveOrganizationResponseDTO",
            '409': "MoveOrganizationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def move_organization_without_preload_content(
        self,
        organization_id: Annotated[StrictStr, Field(description="Enter the id for the organization to be moved under the new parent.")],
        destination_id: Annotated[StrictStr, Field(description="Enter the id for the new parent organization.")],
        fail_early_on_error: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """move_organization

        Use this method to change the parent organization.  Permissions required: Edit IQ Elements

        :param organization_id: Enter the id for the organization to be moved under the new parent. (required)
        :type organization_id: str
        :param destination_id: Enter the id for the new parent organization. (required)
        :type destination_id: str
        :param fail_early_on_error:
        :type fail_early_on_error: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._move_organization_serialize(
            organization_id=organization_id,
            destination_id=destination_id,
            fail_early_on_error=fail_early_on_error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MoveOrganizationResponseDTO",
            '409': "MoveOrganizationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _move_organization_serialize(
        self,
        organization_id,
        destination_id,
        fail_early_on_error,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if organization_id is not None:
            _path_params['organizationId'] = organization_id
        if destination_id is not None:
            _path_params['destinationId'] = destination_id
        # process the query parameters
        if fail_early_on_error is not None:
            
            _query_params.append(('failEarlyOnError', fail_early_on_error))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v2/organizations/{organizationId}/move/destination/{destinationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.policy_alert import PolicyAlert

class TestPolicyAlert(unittest.TestCase):
    """PolicyAlert unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyAlert:
        """Test PolicyAlert
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyAlert`
        """
        model = PolicyAlert()
        if include_optional:
            return PolicyAlert(
                actions = [
                    sonatype_iq_api_client.models.action.Action(
                        action_type_id = '', 
                        target = '', 
                        target_type = '', )
                    ],
                trigger = sonatype_iq_api_client.models.policy_fact.PolicyFact(
                    component_facts = [
                        sonatype_iq_api_client.models.component_fact.ComponentFact(
                            component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                                coordinates = {
                                    'key' : ''
                                    }, 
                                format = '', ), 
                            constraint_facts = [
                                sonatype_iq_api_client.models.constraint_fact.ConstraintFact(
                                    condition_facts = [
                                        sonatype_iq_api_client.models.condition_fact.ConditionFact(
                                            condition_index = 56, 
                                            condition_type_id = '', 
                                            reason = '', 
                                            reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                type = 'SECURITY_VULNERABILITY_REFID', 
                                                value = '', ), 
                                            summary = '', 
                                            trigger_json = '', )
                                        ], 
                                    constraint_id = '', 
                                    constraint_name = '', 
                                    operator_name = '', )
                                ], 
                            display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                                name = '', 
                                parts = [
                                    sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                                        field = '', 
                                        value = '', )
                                    ], ), 
                            hash = '', 
                            pathnames = [
                                ''
                                ], )
                        ], 
                    policy_id = '', 
                    policy_name = '', 
                    policy_violation_id = '', 
                    threat_level = 56, )
            )
        else:
            return PolicyAlert(
        )
        """

    def testPolicyAlert(self):
        """Test PolicyAlert"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_stale_waivers_response_dto import ApiStaleWaiversResponseDTO

class TestApiStaleWaiversResponseDTO(unittest.TestCase):
    """ApiStaleWaiversResponseDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiStaleWaiversResponseDTO:
        """Test ApiStaleWaiversResponseDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiStaleWaiversResponseDTO`
        """
        model = ApiStaleWaiversResponseDTO()
        if include_optional:
            return ApiStaleWaiversResponseDTO(
                stale_waivers = [
                    sonatype_iq_api_client.models.api_stale_waiver_dto.ApiStaleWaiverDTO(
                        comment = '', 
                        constraint_facts = [
                            sonatype_iq_api_client.models.api_constraint_fact_dto.ApiConstraintFactDTO(
                                constraint_id = '', 
                                constraint_name = '', 
                                reasons = [
                                    sonatype_iq_api_client.models.api_condition_fact_reason_dto.ApiConditionFactReasonDTO(
                                        reason = '', )
                                    ], )
                            ], 
                        create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        creator_id = '', 
                        creator_name = '', 
                        expiry_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        policy_id = '', 
                        policy_name = '', 
                        policy_waiver_reason_id = '', 
                        reason_text = '', 
                        scope_owner_id = '', 
                        scope_owner_name = '', 
                        scope_owner_type = '', 
                        stale_evaluations = sonatype_iq_api_client.models.api_stale_evaluations_dto.ApiStaleEvaluationsDTO(
                            applications = [
                                sonatype_iq_api_client.models.api_stale_application_evaluation_dto.ApiStaleApplicationEvaluationDTO(
                                    application = sonatype_iq_api_client.models.api_application_base_dto.ApiApplicationBaseDTO(
                                        contact_user_name = '', 
                                        id = '', 
                                        name = '', 
                                        organization_id = '', 
                                        public_id = '', ), 
                                    stages = [
                                        sonatype_iq_api_client.models.api_stale_evaluation_stage_dto.ApiStaleEvaluationStageDTO(
                                            last_evaluation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            stage_id = '', )
                                        ], )
                                ], 
                            repositories = [
                                sonatype_iq_api_client.models.api_stale_repository_evaluation_dto.ApiStaleRepositoryEvaluationDTO(
                                    repository = sonatype_iq_api_client.models.api_repository_dto.ApiRepositoryDTO(
                                        audit_enabled = True, 
                                        format = '', 
                                        namespace_confusion_protection_enabled = True, 
                                        policy_compliant_component_selection_enabled = True, 
                                        public_id = '', 
                                        quarantine_enabled = True, 
                                        repository_id = '', 
                                        type = '', ), )
                                ], ), 
                        waiver_id = '', )
                    ]
            )
        else:
            return ApiStaleWaiversResponseDTO(
        )
        """

    def testApiStaleWaiversResponseDTO(self):
        """Test ApiStaleWaiversResponseDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_license_legal_copyright_dto import ApiLicenseLegalCopyrightDTO
from sonatype_iq_api_client.models.api_license_legal_file_dto import ApiLicenseLegalFileDTO
from sonatype_iq_api_client.models.api_license_legal_obligation_dto import ApiLicenseLegalObligationDTO
from sonatype_iq_api_client.models.api_license_threat_dtov2 import ApiLicenseThreatDTOV2
from sonatype_iq_api_client.models.component_obligation_attribution_dto import ComponentObligationAttributionDTO
from sonatype_iq_api_client.models.legal_source_link_dto import LegalSourceLinkDTO
from typing import Optional, Set
from typing_extensions import Self

class ApiLicenseLegalDataDTO(BaseModel):
    """
    ApiLicenseLegalDataDTO
    """ # noqa: E501
    attributions: Optional[List[ComponentObligationAttributionDTO]] = None
    component_copyright_id: Optional[StrictStr] = Field(default=None, alias="componentCopyrightId")
    component_copyright_last_updated_at: Optional[datetime] = Field(default=None, alias="componentCopyrightLastUpdatedAt")
    component_copyright_last_updated_by_username: Optional[StrictStr] = Field(default=None, alias="componentCopyrightLastUpdatedByUsername")
    component_copyright_scope_owner_id: Optional[StrictStr] = Field(default=None, alias="componentCopyrightScopeOwnerId")
    component_licenses_id: Optional[StrictStr] = Field(default=None, alias="componentLicensesId")
    component_licenses_last_updated_at: Optional[datetime] = Field(default=None, alias="componentLicensesLastUpdatedAt")
    component_licenses_last_updated_by_username: Optional[StrictStr] = Field(default=None, alias="componentLicensesLastUpdatedByUsername")
    component_licenses_scope_owner_id: Optional[StrictStr] = Field(default=None, alias="componentLicensesScopeOwnerId")
    component_notices_id: Optional[StrictStr] = Field(default=None, alias="componentNoticesId")
    component_notices_last_updated_at: Optional[datetime] = Field(default=None, alias="componentNoticesLastUpdatedAt")
    component_notices_last_updated_by_username: Optional[StrictStr] = Field(default=None, alias="componentNoticesLastUpdatedByUsername")
    component_notices_scope_owner_id: Optional[StrictStr] = Field(default=None, alias="componentNoticesScopeOwnerId")
    copyrights: Optional[List[ApiLicenseLegalCopyrightDTO]] = None
    declared_licenses: Optional[List[StrictStr]] = Field(default=None, alias="declaredLicenses")
    effective_license_status: Optional[StrictStr] = Field(default=None, alias="effectiveLicenseStatus")
    effective_licenses: Optional[List[StrictStr]] = Field(default=None, alias="effectiveLicenses")
    highest_effective_license_threat_group: Optional[ApiLicenseThreatDTOV2] = Field(default=None, alias="highestEffectiveLicenseThreatGroup")
    license_files: Optional[List[ApiLicenseLegalFileDTO]] = Field(default=None, alias="licenseFiles")
    notice_files: Optional[List[ApiLicenseLegalFileDTO]] = Field(default=None, alias="noticeFiles")
    obligations: Optional[List[ApiLicenseLegalObligationDTO]] = None
    observed_licenses: Optional[List[StrictStr]] = Field(default=None, alias="observedLicenses")
    source_links: Optional[List[LegalSourceLinkDTO]] = Field(default=None, alias="sourceLinks")
    __properties: ClassVar[List[str]] = ["attributions", "componentCopyrightId", "componentCopyrightLastUpdatedAt", "componentCopyrightLastUpdatedByUsername", "componentCopyrightScopeOwnerId", "componentLicensesId", "componentLicensesLastUpdatedAt", "componentLicensesLastUpdatedByUsername", "componentLicensesScopeOwnerId", "componentNoticesId", "componentNoticesLastUpdatedAt", "componentNoticesLastUpdatedByUsername", "componentNoticesScopeOwnerId", "copyrights", "declaredLicenses", "effectiveLicenseStatus", "effectiveLicenses", "highestEffectiveLicenseThreatGroup", "licenseFiles", "noticeFiles", "obligations", "observedLicenses", "sourceLinks"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiLicenseLegalDataDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attributions (list)
        _items = []
        if self.attributions:
            for _item_attributions in self.attributions:
                if _item_attributions:
                    _items.append(_item_attributions.to_dict())
            _dict['attributions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in copyrights (list)
        _items = []
        if self.copyrights:
            for _item_copyrights in self.copyrights:
                if _item_copyrights:
                    _items.append(_item_copyrights.to_dict())
            _dict['copyrights'] = _items
        # override the default output from pydantic by calling `to_dict()` of highest_effective_license_threat_group
        if self.highest_effective_license_threat_group:
            _dict['highestEffectiveLicenseThreatGroup'] = self.highest_effective_license_threat_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in license_files (list)
        _items = []
        if self.license_files:
            for _item_license_files in self.license_files:
                if _item_license_files:
                    _items.append(_item_license_files.to_dict())
            _dict['licenseFiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in notice_files (list)
        _items = []
        if self.notice_files:
            for _item_notice_files in self.notice_files:
                if _item_notice_files:
                    _items.append(_item_notice_files.to_dict())
            _dict['noticeFiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in obligations (list)
        _items = []
        if self.obligations:
            for _item_obligations in self.obligations:
                if _item_obligations:
                    _items.append(_item_obligations.to_dict())
            _dict['obligations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in source_links (list)
        _items = []
        if self.source_links:
            for _item_source_links in self.source_links:
                if _item_source_links:
                    _items.append(_item_source_links.to_dict())
            _dict['sourceLinks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiLicenseLegalDataDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "attributions": [ComponentObligationAttributionDTO.from_dict(_item) for _item in obj["attributions"]] if obj.get("attributions") is not None else None,
            "componentCopyrightId": obj.get("componentCopyrightId"),
            "componentCopyrightLastUpdatedAt": obj.get("componentCopyrightLastUpdatedAt"),
            "componentCopyrightLastUpdatedByUsername": obj.get("componentCopyrightLastUpdatedByUsername"),
            "componentCopyrightScopeOwnerId": obj.get("componentCopyrightScopeOwnerId"),
            "componentLicensesId": obj.get("componentLicensesId"),
            "componentLicensesLastUpdatedAt": obj.get("componentLicensesLastUpdatedAt"),
            "componentLicensesLastUpdatedByUsername": obj.get("componentLicensesLastUpdatedByUsername"),
            "componentLicensesScopeOwnerId": obj.get("componentLicensesScopeOwnerId"),
            "componentNoticesId": obj.get("componentNoticesId"),
            "componentNoticesLastUpdatedAt": obj.get("componentNoticesLastUpdatedAt"),
            "componentNoticesLastUpdatedByUsername": obj.get("componentNoticesLastUpdatedByUsername"),
            "componentNoticesScopeOwnerId": obj.get("componentNoticesScopeOwnerId"),
            "copyrights": [ApiLicenseLegalCopyrightDTO.from_dict(_item) for _item in obj["copyrights"]] if obj.get("copyrights") is not None else None,
            "declaredLicenses": obj.get("declaredLicenses"),
            "effectiveLicenseStatus": obj.get("effectiveLicenseStatus"),
            "effectiveLicenses": obj.get("effectiveLicenses"),
            "highestEffectiveLicenseThreatGroup": ApiLicenseThreatDTOV2.from_dict(obj["highestEffectiveLicenseThreatGroup"]) if obj.get("highestEffectiveLicenseThreatGroup") is not None else None,
            "licenseFiles": [ApiLicenseLegalFileDTO.from_dict(_item) for _item in obj["licenseFiles"]] if obj.get("licenseFiles") is not None else None,
            "noticeFiles": [ApiLicenseLegalFileDTO.from_dict(_item) for _item in obj["noticeFiles"]] if obj.get("noticeFiles") is not None else None,
            "obligations": [ApiLicenseLegalObligationDTO.from_dict(_item) for _item in obj["obligations"]] if obj.get("obligations") is not None else None,
            "observedLicenses": obj.get("observedLicenses"),
            "sourceLinks": [LegalSourceLinkDTO.from_dict(_item) for _item in obj["sourceLinks"]] if obj.get("sourceLinks") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.license_legal_metadata_template_api import LicenseLegalMetadataTemplateApi


class TestLicenseLegalMetadataTemplateApi(unittest.TestCase):
    """LicenseLegalMetadataTemplateApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LicenseLegalMetadataTemplateApi()

    def tearDown(self) -> None:
        pass

    def test_delete_attribution_report_template(self) -> None:
        """Test case for delete_attribution_report_template

        """
        pass

    def test_get_all_attribution_report_templates(self) -> None:
        """Test case for get_all_attribution_report_templates

        """
        pass

    def test_get_attribution_report_template_by_id(self) -> None:
        """Test case for get_attribution_report_template_by_id

        """
        pass

    def test_save_attribution_report_template(self) -> None:
        """Test case for save_attribution_report_template

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.api_applied_license_overrides_dto import ApiAppliedLicenseOverridesDTO
from sonatype_iq_api_client.models.api_license_override_dto import ApiLicenseOverrideDTO
from sonatype_iq_api_client.models.component_identifier import ComponentIdentifier

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class LicenseOverridesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_license_override(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to add or update a license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        api_license_override_dto: Annotated[ApiLicenseOverrideDTO, Field(description="Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiLicenseOverrideDTO:
        """add_license_override

        Use this method to add or update a license override to a component for a given owner scope.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to add or update a license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param api_license_override_dto: Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`. (required)
        :type api_license_override_dto: ApiLicenseOverrideDTO
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_license_override_dto=api_license_override_dto,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLicenseOverrideDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_license_override_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to add or update a license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        api_license_override_dto: Annotated[ApiLicenseOverrideDTO, Field(description="Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiLicenseOverrideDTO]:
        """add_license_override

        Use this method to add or update a license override to a component for a given owner scope.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to add or update a license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param api_license_override_dto: Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`. (required)
        :type api_license_override_dto: ApiLicenseOverrideDTO
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_license_override_dto=api_license_override_dto,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLicenseOverrideDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_license_override_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to add or update a license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        api_license_override_dto: Annotated[ApiLicenseOverrideDTO, Field(description="Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """add_license_override

        Use this method to add or update a license override to a component for a given owner scope.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to add or update a license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param api_license_override_dto: Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`. (required)
        :type api_license_override_dto: ApiLicenseOverrideDTO
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_license_override_dto=api_license_override_dto,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLicenseOverrideDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_license_override_serialize(
        self,
        owner_type,
        owner_id,
        api_license_override_dto,
        where,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if where is not None:
            
            _query_params.append(('where', where))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_license_override_dto is not None:
            _body_params = api_license_override_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_license_override(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to delete license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        license_override_id: Annotated[StrictStr, Field(description="Enter the id of the license override you want to delete.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """delete_license_override

        Use this method to delete a license override for a component.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to delete license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param license_override_id: Enter the id of the license override you want to delete. (required)
        :type license_override_id: str
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            license_override_id=license_override_id,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_license_override_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to delete license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        license_override_id: Annotated[StrictStr, Field(description="Enter the id of the license override you want to delete.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """delete_license_override

        Use this method to delete a license override for a component.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to delete license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param license_override_id: Enter the id of the license override you want to delete. (required)
        :type license_override_id: str
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            license_override_id=license_override_id,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_license_override_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to delete license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        license_override_id: Annotated[StrictStr, Field(description="Enter the id of the license override you want to delete.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """delete_license_override

        Use this method to delete a license override for a component.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to delete license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param license_override_id: Enter the id of the license override you want to delete. (required)
        :type license_override_id: str
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            license_override_id=license_override_id,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_license_override_serialize(
        self,
        owner_type,
        owner_id,
        license_override_id,
        where,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if license_override_id is not None:
            _path_params['licenseOverrideId'] = license_override_id
        # process the query parameters
        if where is not None:
            
            _query_params.append(('where', where))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}/{licenseOverrideId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_applied_license_overrides(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"}")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiAppliedLicenseOverridesDTO:
        """get_applied_license_overrides

        Use this method to retrieve the applied license overrides for a component.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param component_identifier: Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"} (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_applied_license_overrides_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"}")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiAppliedLicenseOverridesDTO]:
        """get_applied_license_overrides

        Use this method to retrieve the applied license overrides for a component.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param component_identifier: Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"} (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_applied_license_overrides_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"}")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_applied_license_overrides

        Use this method to retrieve the applied license overrides for a component.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param component_identifier: Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"} (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_applied_license_overrides_serialize(
        self,
        owner_type,
        owner_id,
        component_identifier,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if component_identifier is not None:
            
            _query_params.append(('componentIdentifier', component_identifier))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_applied_license_overrides_for_legal_reviewer(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the owner.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the component format and coordinates.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiAppliedLicenseOverridesDTO:
        """get_applied_license_overrides_for_legal_reviewer

        Use this method to retrieve the applied license overrides for a given component and owner.  Permissions required: Review Legal Obligations For Components Licenses

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the owner. (required)
        :type owner_id: str
        :param component_identifier: Enter the component format and coordinates. (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_for_legal_reviewer_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_applied_license_overrides_for_legal_reviewer_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the owner.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the component format and coordinates.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiAppliedLicenseOverridesDTO]:
        """get_applied_license_overrides_for_legal_reviewer

        Use this method to retrieve the applied license overrides for a given component and owner.  Permissions required: Review Legal Obligations For Components Licenses

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the owner. (required)
        :type owner_id: str
        :param component_identifier: Enter the component format and coordinates. (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_for_legal_reviewer_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_applied_license_overrides_for_legal_reviewer_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the owner.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the component format and coordinates.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_applied_license_overrides_for_legal_reviewer

        Use this method to retrieve the applied license overrides for a given component and owner.  Permissions required: Review Legal Obligations For Components Licenses

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the owner. (required)
        :type owner_id: str
        :param component_identifier: Enter the component format and coordinates. (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_for_legal_reviewer_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_applied_license_overrides_for_legal_reviewer_serialize(
        self,
        owner_type,
        owner_id,
        component_identifier,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if component_identifier is not None:
            
            _query_params.append(('componentIdentifier', component_identifier))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}/legalReviewer',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.configure_artifactory_connection_api import ConfigureArtifactoryConnectionApi


class TestConfigureArtifactoryConnectionApi(unittest.TestCase):
    """ConfigureArtifactoryConnectionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfigureArtifactoryConnectionApi()

    def tearDown(self) -> None:
        pass

    def test_add_artifactory_connection(self) -> None:
        """Test case for add_artifactory_connection

        """
        pass

    def test_delete_artifactory_connection(self) -> None:
        """Test case for delete_artifactory_connection

        """
        pass

    def test_get_artifactory_connection(self) -> None:
        """Test case for get_artifactory_connection

        """
        pass

    def test_get_owner_artifactory_connection(self) -> None:
        """Test case for get_owner_artifactory_connection

        """
        pass

    def test_test_artifactory_connection(self) -> None:
        """Test case for test_artifactory_connection

        """
        pass

    def test_test_artifactory_connection1(self) -> None:
        """Test case for test_artifactory_connection1

        """
        pass

    def test_update_artifactory_connection(self) -> None:
        """Test case for update_artifactory_connection

        """
        pass

    def test_update_owner_artifactory_connection_status(self) -> None:
        """Test case for update_owner_artifactory_connection_status

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.prioritized_component import PrioritizedComponent

class TestPrioritizedComponent(unittest.TestCase):
    """PrioritizedComponent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PrioritizedComponent:
        """Test PrioritizedComponent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PrioritizedComponent`
        """
        model = PrioritizedComponent()
        if include_optional:
            return PrioritizedComponent(
                action = '',
                component_hash = '',
                component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                dependency_type = '',
                display_name = '',
                has_auto_waiver = True,
                has_expired_waiver = True,
                has_fail_action_on_component = True,
                has_same_violations_on_main = True,
                has_soon_to_expire_waiver = True,
                highest_reachable_threat = 56,
                highest_threat = 56,
                highest_threat_policy_constraint_name = '',
                highest_threat_policy_name = '',
                is_all_violations_waived = True,
                priority = 56,
                remediation_type = 'next-no-violations',
                remediation_version = '',
                security_reachable = True,
                waived_violations_count = 56,
                waiver_expiration_details = ''
            )
        else:
            return PrioritizedComponent(
        )
        """

    def testPrioritizedComponent(self):
        """Test PrioritizedComponent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_dependency_tree_node_dto import ApiDependencyTreeNodeDTO

class TestApiDependencyTreeNodeDTO(unittest.TestCase):
    """ApiDependencyTreeNodeDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiDependencyTreeNodeDTO:
        """Test ApiDependencyTreeNodeDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiDependencyTreeNodeDTO`
        """
        model = ApiDependencyTreeNodeDTO()
        if include_optional:
            return ApiDependencyTreeNodeDTO(
                children = [
                    sonatype_iq_api_client.models.api_dependency_tree_node_dto.ApiDependencyTreeNodeDTO(
                        children = [
                            sonatype_iq_api_client.models.api_dependency_tree_node_dto.ApiDependencyTreeNodeDTO(
                                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                    coordinates = {
                                        'key' : ''
                                        }, 
                                    format = '', ), 
                                direct = True, 
                                package_url = '', )
                            ], 
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            format = '', ), 
                        direct = True, 
                        package_url = '', )
                    ],
                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                direct = True,
                package_url = ''
            )
        else:
            return ApiDependencyTreeNodeDTO(
        )
        """

    def testApiDependencyTreeNodeDTO(self):
        """Test ApiDependencyTreeNodeDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.auto_policy_waiver_exclusions_api import AutoPolicyWaiverExclusionsApi


class TestAutoPolicyWaiverExclusionsApi(unittest.TestCase):
    """AutoPolicyWaiverExclusionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AutoPolicyWaiverExclusionsApi()

    def tearDown(self) -> None:
        pass

    def test_add_auto_policy_waive_exclusion(self) -> None:
        """Test case for add_auto_policy_waive_exclusion

        """
        pass

    def test_delete_auto_policy_waiver_exclusion(self) -> None:
        """Test case for delete_auto_policy_waiver_exclusion

        """
        pass

    def test_get_auto_policy_waiver_exclusions(self) -> None:
        """Test case for get_auto_policy_waiver_exclusions

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_owner_artifactory_connection_dto import ApiOwnerArtifactoryConnectionDTO

class TestApiOwnerArtifactoryConnectionDTO(unittest.TestCase):
    """ApiOwnerArtifactoryConnectionDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiOwnerArtifactoryConnectionDTO:
        """Test ApiOwnerArtifactoryConnectionDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiOwnerArtifactoryConnectionDTO`
        """
        model = ApiOwnerArtifactoryConnectionDTO()
        if include_optional:
            return ApiOwnerArtifactoryConnectionDTO(
                artifactory_connection = sonatype_iq_api_client.models.api_artifactory_connection_dto.ApiArtifactoryConnectionDTO(
                    artifactory_connection_id = '', 
                    base_url = '', 
                    is_anonymous = True, 
                    owner_id = '', 
                    owner_type = 'application', 
                    password = '', 
                    username = '', ),
                artifactory_connection_status = sonatype_iq_api_client.models.api_artifactory_connection_status_response_dto.ApiArtifactoryConnectionStatusResponseDTO(
                    allow_change = True, 
                    allow_override = True, 
                    enabled = True, 
                    inherited_from_org_enabled = True, 
                    inherited_from_organization_id = '', 
                    inherited_from_organization_name = '', ),
                owner_dto = sonatype_iq_api_client.models.api_owner_dto.ApiOwnerDTO(
                    owner_id = '', 
                    owner_name = '', 
                    owner_public_id = '', 
                    owner_type = '', )
            )
        else:
            return ApiOwnerArtifactoryConnectionDTO(
        )
        """

    def testApiOwnerArtifactoryConnectionDTO(self):
        """Test ApiOwnerArtifactoryConnectionDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_page_result_prioritized_component import ApiPageResultPrioritizedComponent

class TestApiPageResultPrioritizedComponent(unittest.TestCase):
    """ApiPageResultPrioritizedComponent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiPageResultPrioritizedComponent:
        """Test ApiPageResultPrioritizedComponent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiPageResultPrioritizedComponent`
        """
        model = ApiPageResultPrioritizedComponent()
        if include_optional:
            return ApiPageResultPrioritizedComponent(
                page = 56,
                page_count = 56,
                page_size = 56,
                results = [
                    sonatype_iq_api_client.models.prioritized_component.PrioritizedComponent(
                        action = '', 
                        component_hash = '', 
                        component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        dependency_type = '', 
                        display_name = '', 
                        has_auto_waiver = True, 
                        has_expired_waiver = True, 
                        has_fail_action_on_component = True, 
                        has_same_violations_on_main = True, 
                        has_soon_to_expire_waiver = True, 
                        highest_reachable_threat = 56, 
                        highest_threat = 56, 
                        highest_threat_policy_constraint_name = '', 
                        highest_threat_policy_name = '', 
                        is_all_violations_waived = True, 
                        priority = 56, 
                        remediation_type = 'next-no-violations', 
                        remediation_version = '', 
                        security_reachable = True, 
                        waived_violations_count = 56, 
                        waiver_expiration_details = '', )
                    ],
                total = 56
            )
        else:
            return ApiPageResultPrioritizedComponent(
        )
        """

    def testApiPageResultPrioritizedComponent(self):
        """Test ApiPageResultPrioritizedComponent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
